
package interfazgrafica6;

import javax.swing.JLabel;

public class Componentes {

    private JLabel jLabelVisualizaPosicionRaton;  
    private AreaDibujo areaDibujo;
    private JLabel jLabelVisualizaPulsacionesBoton;
    private JButtonPersonalizado jButtonPersonalizadoContar;   
    private int contadorPulsacionesBoton;
    
    public JLabel getjLabelVisualizaPosicionRaton() {
        return jLabelVisualizaPosicionRaton;
    }

    public void setjLabelVisualizaPosicionRaton(JLabel jLabelVisualizaPosicionRaton) {
        this.jLabelVisualizaPosicionRaton = jLabelVisualizaPosicionRaton;
    }

    public AreaDibujo getAreaDibujo() {
        return areaDibujo;
    }

    public void setAreaDibujo(AreaDibujo areaDibujo) {
        this.areaDibujo = areaDibujo;
    }  
    
    public JLabel getjLabelVisualizaPulsacionesBoton() {
        return jLabelVisualizaPulsacionesBoton;
    }

    public void setjLabelVisualizaPulsacionesBoton(JLabel jLabelVisualizaPulsacionesBoton) {
        this.jLabelVisualizaPulsacionesBoton = jLabelVisualizaPulsacionesBoton;
    }    
    
    public JButtonPersonalizado getjButtonPersonalizadoContar() {
        return jButtonPersonalizadoContar;
    }

    public void setjButtonPersonalizadoContar(JButtonPersonalizado jButtonPersonalizadoContar) {
        this.jButtonPersonalizadoContar = jButtonPersonalizadoContar;
    }

    public int getContadorPulsacionesBoton() {
        return contadorPulsacionesBoton;
    }

    public void setContadorPulsacionesBoton(int contadorPulsacionesBoton) {
        this.contadorPulsacionesBoton = contadorPulsacionesBoton;
    }    
}
